==> babel-plugin-house-1.0.0.tgz: package/lib/index.js <==
"use strict";

function _createForOfIteratorHelper(o, allowArrayLike) { var it; if (typeof Symbol === "undefined" || o[Symbol.iterator] == null) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = o[Symbol.iterator](); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }

const babel = require('babel-core');

const t = require('babel-types');

const visitor = {
  FunctionDeclaration(path) {
    const node = path.node;

    if (t.isIdentifier(path.node.id) && node.id.name === 'executeAction') {
      if (t.isBlockStatement(node.body)) {
        var _iterator = _createForOfIteratorHelper(node.body.body),
            _step;

        try {
          for (_iterator.s(); !(_step = _iterator.n()).done;) {
            let item = _step.value;

            if (t.isExpressionStatement(item) && t.isCallExpression(item.expression)) {
              if (t.isIdentifier(item.expression.callee) && item.expression.callee.name === 'endAction') {
                let args = item.expression.arguments;
                args.unshift(t.identifier('actionName'));
                break;
              } // console.log(item);

            }
          }
        } catch (err) {
          _iterator.e(err);
        } finally {
          _iterator.f();
        }
      }
    }

    if (t.isIdentifier(path.node.id) && node.id.name === 'endAction') {
      if (t.isBlockStatement(node.body)) {
        var _iterator2 = _createForOfIteratorHelper(node.body.body),
            _step2;

        try {
          for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
            let item = _step2.value;

            if (t.isExpressionStatement(item) && t.isCallExpression(item.expression)) {
              if (t.isIdentifier(item.expression.callee) && item.expression.callee.name === 'spyReportEnd') {
                console.log(item.expression);

                var _iterator3 = _createForOfIteratorHelper(item.expression.arguments),
                    _step3;

                try {
                  for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
                    let arg = _step3.value;

                    if (t.isObjectExpression(arg)) {
                      const attr = t.objectProperty(t.identifier('actionName'), t.identifier('actionName'));
                      arg.properties.unshift(attr);
                    }
                  }
                } catch (err) {
                  _iterator3.e(err);
                } finally {
                  _iterator3.f();
                }
              }
            }
          }
        } catch (err) {
          _iterator2.e(err);
        } finally {
          _iterator2.f();
        }
      }
    }
  },

  VariableDeclaration(path) {
    const node = path.node;

    if (node.kind === 'let' || node.kind === 'const') {
      // 变量声明的kind, 可以是var let const
      // 然后第二个参数是声明的变量，let a, b, c这里的a, b, c就是node.declarations
      const varNode = t.variableDeclaration('var', node.declarations);
      path.replaceWith(varNode);
    }
  },

  Literal(path) {
    const node = path.node;

    if (node.value === 'hahaha') {
      node.value = 'hahahahjhjhj';
    }
  }

};

module.exports = function () {
  // 名称必须是visitor
  return {
    visitor
  };
};

==> babel-plugin-house-1.0.2.tgz: package/lib/index.js <==
"use strict";

function _createForOfIteratorHelper(o, allowArrayLike) { var it; if (typeof Symbol === "undefined" || o[Symbol.iterator] == null) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = o[Symbol.iterator](); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }

const babel = require('babel-core');

const t = require('babel-types');

const visitor = {
  FunctionDeclaration(path) {
    const node = path.node;

    if (t.isIdentifier(path.node.id) && node.id.name === 'executeAction') {
      if (t.isBlockStatement(node.body)) {
        var _iterator = _createForOfIteratorHelper(node.body.body),
            _step;

        try {
          for (_iterator.s(); !(_step = _iterator.n()).done;) {
            let item = _step.value;

            if (t.isExpressionStatement(item) && t.isCallExpression(item.expression)) {
              if (t.isIdentifier(item.expression.callee) && item.expression.callee.name === 'endAction') {
                let args = item.expression.arguments;
                args.unshift(t.identifier('actionName'));
                break;
              } // console.log(item);

            }
          }
        } catch (err) {
          _iterator.e(err);
        } finally {
          _iterator.f();
        }
      }
    }

    if (t.isIdentifier(path.node.id) && node.id.name === 'endAction') {
      if (t.isBlockStatement(node.body)) {
        var _iterator2 = _createForOfIteratorHelper(node.body.body),
            _step2;

        try {
          for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
            let item = _step2.value;

            if (t.isExpressionStatement(item) && t.isCallExpression(item.expression)) {
              if (t.isIdentifier(item.expression.callee) && item.expression.callee.name === 'spyReportEnd') {
                console.log(item.expression);

                var _iterator3 = _createForOfIteratorHelper(item.expression.arguments),
                    _step3;

                try {
                  for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
                    let arg = _step3.value;

                    if (t.isObjectExpression(arg)) {
                      const attr = t.objectProperty(t.identifier('actionName'), t.identifier('actionName'));
                      arg.properties.unshift(attr);
                    }
                  }
                } catch (err) {
                  _iterator3.e(err);
                } finally {
                  _iterator3.f();
                }
              }
            }
          }
        } catch (err) {
          _iterator2.e(err);
        } finally {
          _iterator2.f();
        }
      }
    }
  },

  VariableDeclaration(path) {
    const node = path.node;

    if (node.kind === 'let' || node.kind === 'const') {
      // 变量声明的kind, 可以是var let const
      // 然后第二个参数是声明的变量，let a, b, c这里的a, b, c就是node.declarations
      const varNode = t.variableDeclaration('var', node.declarations);
      path.replaceWith(varNode);
    }
  },

  Literal(path) {
    const node = path.node;

    if (node.value === 'hahaha') {
      node.value = 'hahahakakaka';
    }
  }

};

module.exports = function () {
  // 名称必须是visitor
  return {
    visitor
  };
};
